@@ -2,7 +2,8 @@ class Place:
   def __init__(self, params):
     self.text = params['text']
     self.type = params['type']
-    self.__initmark = params['initmark']
+    # self.__initmark = params['initmark']
+    self._tokens = params['initmark']
 
   def __repr__(self):
     return f'<Place(text={self.text}, type={self.type}, tokens={self.tokens})>'
@@ -20,16 +21,20 @@ class Place:
 
   @property
   def tokens(self):
-    if self.__initmark is None:
+    if self._tokens is None:
       return
 
     if self.type == 'UNIT':
-      token = self.__initmark.replace('`()','')
+      token = self._tokens.replace('`()','')
       return int(token)
     else:
       tokens = []
-      for text in self.__initmark.replace('\n','').split('++'):
+      for text in self._tokens.replace('\n','').split('++'):
         token = text.split('`')
         tokens += [token[1]] * int(token[0])
 
-      return tokens
\ No newline at end of file
+      return tokens
+  
+  @tokens.setter
+  def tokens(self, tokens):
+    self._tokens = tokens
\ No newline at end of file
