@@ -1,3 +1,6 @@
+from typing import Type
+
+
 class Transition:
   def __init__(self, params):
     self.text = params['text']
@@ -23,4 +26,11 @@ class Transition:
       return
 
     time = int(self._time.replace('@+',''))
-    return time
\ No newline at end of file
+    return time
+
+  @time.setter
+  def time(self, time):
+    if type(time) == int:
+      raise TypeError('time attribute must be a string')
+
+    self._time = time
\ No newline at end of file
